from canonmap.models.entity_mapping_request import EntityMappingRequest

class EntityMapper:
    def __init__(self) -> None:
        pass

    def map(self, config: EntityMappingRequest) -> None:
        pass